@@ -58,8 +58,10 @@ def _get_lyrics(page_title):
 		return content[content.find("<lyrics>") + len("<lyrics>") : content.find("</lyrics>")].strip()
 	
 def get_lyrics(*keywords):
-	"""Returns the lyrics for this track as ((artist, title), lyrics) or None if not found
-	keywords should include the artist and title name of the track"""
+	"""Search for and return lyrics
+	keywords should include the title and artist
+	example:
+	lyrics = get_lyrics("iron maiden", "fear of the dark")"""
 	title = _search(" ".join(keywords))
 	if not title:
 		return
